bl_info = {
    'name': 'Export: Transformations to POV-Ray Arrays',
    'description': 'Export the transformations from selected objects to POV-Ray arrays containing scale, rotation and positional data.',
    'author': 'Samuel Benge',
    'version': (0, 0, 1),
    'blender': (2, 6, 2),
    'location': 'File > Export > Transformations to POV-Ray Arrays (.jsx)',
    "warning": "",
    "wiki_url": "",
    "tracker_url": "",
    'category': 'Import-Export',
    }


import bpy
import os
import math

def write_some_data(context, filepath):
    selection = bpy.context.selected_objects
    print("exporting object transformations...")
    #f = open(os.path.join(fnPath, fnBase + fnExt), 'w', encoding='utf-8')
    f = open(filepath, 'w', encoding='utf-8')
    
    f.write("#declare ")
    f.write(bpy.path.display_name_from_filepath(filepath))
    f.write(" =")
    f.write("\n array[%s" % len(selection))
    f.write("]{\n")
    
    for obj in selection:
    
        print(" ", obj.name)
        f.write("  array[3]{\n")
        
        f.write("   <")
        f.write("%s, " % obj.scale[0])
        f.write("%s, " % obj.scale[1])
        f.write("%s>,\n" % obj.scale[2])
    
        DX = math.degrees(obj.rotation_euler[0])
        DY = math.degrees(obj.rotation_euler[1])
        DZ = math.degrees(obj.rotation_euler[2])
        
        f.write("   <")
        f.write("%s, " % DX)
        f.write("%s, " % DY)
        f.write("%s>,\n" % DZ)
        
        f.write("   <")
        f.write("%s, " % obj.location[0])
        f.write("%s, " % obj.location[1])
        f.write("%s>\n" % obj.location[2])
        f.write("  }\n")
    
    f.write(" }")
    
    print("finished.")
    
    f.close()
    
    return {'FINISHED'}

from bpy_extras.io_utils import ExportHelper
from bpy.props import StringProperty, BoolProperty, EnumProperty
from bpy.types import Operator


class ExportTransformsToPOVArrays(Operator, ExportHelper):
    '''export transformations of selected objects to POV-Ray arrays'''
    bl_idname = "export_transforms.pov_arrays"
    bl_label = "Export Transformations"

    filename_ext = ".inc"

    filter_glob = StringProperty(
            default="*.inc",
            options={'HIDDEN'},
            )

    def execute(self, context):
        return write_some_data(context, self.filepath)


def menu_func_export(self, context):
    self.layout.operator(ExportTransformsToPOVArrays.bl_idname, text="Transformations to POV-Ray Arrays")


def register():
    bpy.utils.register_class(ExportTransformsToPOVArrays)
    bpy.types.INFO_MT_file_export.append(menu_func_export)


def unregister():
    bpy.utils.unregister_class(ExportTransformsToPOVArrays)
    bpy.types.INFO_MT_file_export.remove(menu_func_export)


if __name__ == "__main__":
    register()

    # test call
    bpy.ops.export_transforms.pov_arrays('INVOKE_DEFAULT')